import { Package } from "./package.js";
import debug from "debug";
import { usePosition } from "./react/hooks/use-position.js";
import { watchPosition } from "./watch-position.js";
import { usePositionWatch } from "./react/hooks/use-position-watch.js";
import { WithPositionWatch } from "./react/components/with-position-watch.js";
import { checkPermissions } from "./check-permissions.js";
import { makePositionValueUpdateOperations } from "./make-position-value-update-operations.js";
import { requestPermissions } from "./request-permissions.js";
import { getPosition } from "./get-position.js";
import { updatePosition } from "./update-position.js";
import { makePositionInsertOperations } from "./make-position-insert-operations.js";
import { insertPosition } from "./insert-position.js";
import { applyRequiredPackagesInMinilinks } from "./apply-required-packages-in-minilinks.js";
import { REQUIRED_PACKAGES_IN_MINILINKS } from "./required-packages-in-minilnks.js";
import { clearWatch } from "./clear-watch.js";
/**
 *
 * @example
 * #### Create a decorator from another decorator
```ts
const deep = new DeepClient({token: ''});
const anotherDeepDecorator = createAnotherDecorator(deep); // Note that this step is optional and showed only to demonstrate that you can create a decorator from another decorator and have a chain of decorators
const geolocationDeepDecorator = createAdditionalFeatureDecorator(anotherDeepDecorator);
await geolocationDeepDecorator.applyRequiredPackagesInMinilinks();
```
 */
export function createGeolocationDecorator(deep) {
    const log = debug(`@deep-foundation/capacitor-geolocation:${createGeolocationDecorator.name}`);
    log({ deep });
    const _package = new Package({ deep });
    log({ _package });
    const result = {
        ...deep,
        "@deep-foundation/capacitor-geolocation": _package,
        capacitorGeolocationPackage: _package,
        requiredPackagesInMinilinksToApply: [
            ...("requiredPackagesInMinilinksToApply" in deep
                ? deep.requiredPackagesInMinilinksToApply
                : []),
            ...REQUIRED_PACKAGES_IN_MINILINKS,
        ],
        applyRequiredPackagesInMinilinks: applyRequiredPackagesInMinilinks,
        insertPosition: insertPosition,
        makePositionInsertOperations: makePositionInsertOperations,
        updatePosition: updatePosition,
        getPosition: getPosition,
        makeUpdatePositionOperations: makePositionValueUpdateOperations,
        clearWatch: clearWatch,
        checkPermissions: checkPermissions,
        requestPermissions: requestPermissions,
        watchPosition: watchPosition,
        usePositionWatch: usePositionWatch,
        usePosition: usePosition,
        WithPositionWatch: WithPositionWatch,
    };
    Object.setPrototypeOf(result, Object.getPrototypeOf(deep));
    log({ result });
    return result;
}
